@@ -19,7 +19,7 @@ use LWP::UserAgent 6.02;
 use LWP::Protocol::https 6.02;
 use JSON::MaybeXS;
 
-our $VERSION = 'v0.55.2'; # TRIAL VERSION
+our $VERSION = 'v0.55.5'; # TRIAL VERSION
 
 # CF credentials
 has '_user' => (
@@ -70,9 +70,8 @@ method _apiCall ( $act is ro, %args is ro ) {
     return $info->{response};}
 
 # all API calls are implemented through autoloading, the action is the method
-sub AUTOLOAD {
+method AUTOLOAD {
     our $AUTOLOAD;
-    my $self = shift;
     # pull action out of f.q. method name
     my $act  = $AUTOLOAD =~ s/.*:://r;
     return $self->_apiCall( $act, @_ );}
@@ -92,7 +91,9 @@ CloudFlare::Client - Object Orientated Interface to CloudFlare client API
 
 =head1 VERSION
 
-version v0.55.2
+version v0.55.5
+
+=for test_synopsis my ( $CF_USER, $CF_KEY, $ZONE, $INTERVAL);
 
 =head1 SYNOPSIS
 
@@ -126,8 +127,6 @@ Construct a new API object
         user   => $CF_USER,
         apikey => $CF_KEY);
 
-=for test_synopsis my ( $CF_USER, $CF_KEY, $ZONE, $INTERVAL);
-
 =head1 SEE ALSO
 
 Please see those modules/websites for more information related to this module.
@@ -202,7 +201,7 @@ Thanks to CloudFlare providing an awesome free service with an API
 
 =for stopwords Peter Roberts
 
-Peter Roberts <me+dev@peter-r.co.uk>
+Peter Roberts <me+github@peter-r.co.uk>
 
 =head1 AUTHOR
 
@@ -210,7 +209,7 @@ Peter Roberts <me+dev@peter-r.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Peter Roberts.
+This software is Copyright (c) 2016 by Peter Roberts.
 
 This is free software, licensed under:
 
