@@ -9,7 +9,7 @@ use Type::Utils 0.039_12 -all;
 use Types::Standard qw( Enum Maybe);
 use Readonly;
 
-our $VERSION = 'v0.55.2'; # TRIAL VERSION
+our $VERSION = 'v0.55.5'; # TRIAL VERSION
 
 class_type 'LWP::UserAgent';
 declare CFCode, as Enum[qw( E_UNAUTH E_INVLDINPUT E_MAXAPI)];
@@ -29,7 +29,7 @@ CloudFlare::Client::Types - Types for Cloudflare::Client
 
 =head1 VERSION
 
-version v0.55.2
+version v0.55.5
 
 =head1 SYNOPSIS
 
@@ -55,7 +55,7 @@ L<CloudFlare::Client|CloudFlare::Client>
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc CloudFlare::Client::Types
+  perldoc CloudFlare::Client
 
 =head2 Websites
 
@@ -103,7 +103,7 @@ Peter Roberts <me+dev@peter-r.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Peter Roberts.
+This software is Copyright (c) 2016 by Peter Roberts.
 
 This is free software, licensed under:
 
